SendSyncError

Trait SendSyncError 

pub trait SendSyncError:
    Any
    + Error
    + Send
    + Sync
    + 'static {
    // Required method
    fn as_any(&self) -> &dyn Any;
}
Any error that satisfies this trait’s bounds can be used in a ErrorUnion

Required Methods

fn as_any(&self) -> &dyn Any

Converts this SendSynError to Any.

Warning: Use carefully since Any is this type, not the underlying type. e.g. For x: Box<dyn SendSyncError> with x.as_any(), the type yielded is Box<dyn SendSyncError> so functions like x.is::<T>() will not work as expected. While one would probably want (&*x as &dyn Any) which is the underlying and x.is::<T>() will work as expected.

The main use case for this function is when x: &dyn SendSyncError. In such case x.is::<T>() will likely work as intended.